docx\_parser\_converter.docx\_to\_txt.docx\_processor module
============================================================

.. automodule:: docx_parser_converter.docx_to_txt.docx_processor
   :members:
   :undoc-members:
   :show-inheritance:
